@@ -3,6 +3,7 @@ from .engines import mysqlDocker
 from .engines import mongoDocker
 from .engines import fsDefault
 from .engines import dsDefault
+from .engines import dsDefault2
 from .engines import svrDefault
 from .engines import vsDefault
 # Entry Function
@@ -22,6 +23,8 @@ def start(config):
         MsqModule = fsDefault
     elif (DB_ENGINE == 'dsDefault'):
         MsqModule = dsDefault
+    elif (DB_ENGINE == 'dsDefault2'):
+        MsqModule = dsDefault2
     elif (DB_ENGINE == 'svrDefault'):
         MsqModule = svrDefault
     elif (DB_ENGINE == 'vsDefault'):
